@@ -7,6 +7,7 @@ from pydantic import BaseModel
 from typing import Any, Dict
 
 from .bedwarsstats import (
+    CosmeticBedwarsStats,
     OverallBedwarsStats,
     PracticeBedwarsStats
 )
@@ -68,7 +69,8 @@ def get_user_stats() -> Dict[str, Any]:
                 bridge_duels=duelData,
                 skywars_duels=duelData,
                 overall_bedwars=bedwarsData,
-                practice_bedwars=bedwarsData["practice"]
+                practice_bedwars=bedwarsData["practice"],
+                cosmetics_bedwars=bedwarsData
             )
 
             return stats_object
@@ -86,4 +88,5 @@ class MinecraftStats(BaseModel):
     skywars_duels: SkyWarsDuelStats
 
     overall_bedwars: OverallBedwarsStats
-    practice_bedwars: PracticeBedwarsStats
\ No newline at end of file
+    practice_bedwars: PracticeBedwarsStats
+    cosmetics_bedwars: CosmeticBedwarsStats
\ No newline at end of file
